import sys
import json
import requests
import dataapiclient
import dataapiclient.models as models

if (len(sys.argv) < 5):
    print("Missing arguments.")
    exit()

server = sys.argv[1]
project_id = sys.argv[2]
username = sys.argv[3]
password = sys.argv[4]

client = dataapiclient.DapresyDataAPIDocumentation(server)

# authentication
auth_payload = models.TokenRequest(username=username, password=password)
token_response = client.account.get_token(auth_payload)
headers = {
    "Authorization" : "Bearer " + token_response.access_token
    }
    
# get tags
response = client.tags.get_import_tags(project_id, headers)

# post tags
taglist = []
taglist.append(models.ImportTag(tagid = None, tagname = "testTag"))
post_tags_payload = models.TagsDTO(tags=taglist)
response = client.tags.post_import_tags(post_tags_payload, project_id, headers)

# delete tags
for tag in response.data["Tags"]:
    if tag["tagname"] == "testTag":
        taglist = []
        taglist.append(tag)
        delete_tags_payload = models.TagsDTO(tags=taglist)
        response = client.tags.delete_import_tags(delete_tags_payload, project_id, headers)
        break

# import
with open('data/json/importExample.json') as json_file:
    import_payload = json.load(json_file)
    response = client.import_model.post_import(import_payload, project_id, headers)

# import csv
upload_response = models.UploadResponse()
with open("data/csv/importData.csv") as csv_file:
    file_dict = {"importData.csv": csv_file}
    server = server if server.endswith('/') else server + '/'
    r = requests.post(server + "api/v1/project/" + project_id + "/import/upload", files=file_dict, headers=headers)
    upload_response = json.loads(r.content)
with open('data/csv/importExampleCsv.json') as json_file:
    import_csv_payload = json.load(json_file)
    import_csv_payload["ImportContext"]["FileName"] = upload_response["FileName"]
    import_csv_payload["ImportContext"]["TempFileGUID"] = upload_response["tempFileGuid"]
    response = client.import_model.post_import(import_csv_payload, project_id, headers)

# get imported batches
get_batches_payload = models.BatchFilterInput()
response = client.import_model.batches(get_batches_payload, project_id, headers)

# delete imported batches
delete_batches_payload = models.DeleteBatchesInput(batches_to_delete=[1,2])
response = client.import_model.delete_batches(delete_batches_payload, project_id, headers)

# activate/deactivate batches
activate_batches_payload = models.ActivateInput(ids_to_activate=[1,2], ids_to_deactivate=[3,4])
response = client.activation.activate(activate_batches_payload, project_id, headers)

# activation history
activation_history_payload = models.ActivationHistoryFilterInput()
response = client.activation.history(activation_history_payload, project_id, headers)